% Joachim Behar, 04-05-2017
% Bioenergetics and Bioelectric Systems Lab
% Technion, Haifa, Israel
%
% When using this model, please cite:
%   Behar, Joachim, et al. "The Autonomic Nervous System Regulates the Heart 
%   Rate through cAMP-PKA Dependent and Independent Coupled-Clock Pacemaker 
%   Cell Mechanisms." Frontiers in Physiology 7 (2016).
%
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

clear all; close all; clc;

%% constants
con = load_constants;
LINEWITH = 2;
con.ISO = 0; % 100 [nM] modulates activation of Beta-adrenergic receptor (B-AR)
con.CCh = 0; % concentration of carbachol [nM]
con.ALL_VAR = 0; % outputting all the currents? (1:yes, 0:no)

% == no caged cAMP
con.cAB_Conc = 0;
con.cAB_on_rate = 0;
con.cAB_off_rate = 0;

% == caged cAMP
% con.cAB_Conc = 50e-3; % mM -> same value as in the paper
% con.cAB_on_rate = 10e-5; % 10e-3; % mM-1.ms-1
% con.cAB_off_rate = 300e-3; % ms-1

% == caged ISO
% con.cAB_Conc = 3e3; %; % in nM
% con.cAB_on_rate = 10e-7; % nM-1.ms-1
% con.cAB_off_rate = 0.11; % ms-1

%% solver
if con.ALL_VAR % initial conditions
    M = diag([ones(36,1); 0.001*ones(6,1); 1]); % mass matrix - 44 variables
    Finit = [0.0001; 0.000223; 0.029; 1.35; 0.00005; 0.22; 0.69; 0.042; 0.089; ...
        0.032; 0.7499955; 3.4e-6; 1.1e-6; 0.25;
        -65; 0; 1; 1; 0; 0; 1; 0; 1; 0; 1; 1; 0; 0; 1; % membrane clock 
        19.73; 0.23; 0.06; 0.02; 0.06; 1.75e-6;
        0.0004; 0.1*ones(6,1); 1]; %
else % initial conditions with only the coupled variables
    M = diag(ones(36,1)); % 36 variables + adding cAMP buffer (11-01-2016)
    Finit = [0.0001; 0.000223; 0.029; 1.35; 0.00005; 0.22; 0.69; 0.042; 0.089; ...
        0.032; 0.7499955; 3.4e-6; 1.1e-6; 0.25;
        -65; 0; 1; 1; 0; 0; 1; 0; 1; 0; 1; 1; 0; 0; 1;
        19.73; 0.23; 0.06; 0.02; 0.06; 1.75e-6;
        0.0004];
end

opts = odeset('Mass',M);
[t,y] = ode15s(@update_I,0:20000,Finit,opts,con);

%% plots
close all;
START = 93000;
STOP = 96000;
name = 'img/current_figure_new_modulation';
[pks,loc] = findpeaks(y(:,15),'MinPeakHeight',0.01,'MinPeakDistance',200);
HR = 60./diff(loc)*1000;
ax(1) = subplot(211); plot(t/1000,y(:,15));
hold on, plot(loc/1000,y(loc,15),'+r')
ylabel('Amplitude [mV]'); xlabel('Time (sec)');
ax(2) = subplot(212); plot(loc(2:end)/1000,HR);
ylabel('AP firing rate [bpm]'); xlabel('Time (sec)');
linkaxes(ax,'x');
xlim([1000/1000 t(end)/1000]);

